@@ -7,9 +7,9 @@ use warnings;
 use 5.8.0;
 
 package Net::DHCP::Constants;
-$Net::DHCP::Constants::VERSION = '0.7_007'; # TRIAL
-
-$Net::DHCP::Constants::VERSION = '0.7007';# standard module declaration
+$Net::DHCP::Constants::VERSION = '0.7_008'; # TRIAL
+$Net::DHCP::Constants::VERSION = '0.7008';
+# standard module declaration
 our ( @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
 use Exporter;
 @ISA     = qw(Exporter);
@@ -441,7 +441,7 @@ our %DHO_FORMATS = (
     DHO_DHCP_REBINDING_TIME()         => 'int',
     DHO_VENDOR_CLASS_IDENTIFIER()     => 'string',
 
-    DHO_DHCP_CLIENT_IDENTIFIER()      => 'clientid',
+    DHO_DHCP_CLIENT_IDENTIFIER()      => 'clientid',  # rfc 2132 section 9.14
     DHO_NWIP_DOMAIN_NAME()            => 'string',    # rfc 2242
 
     DHO_NWIP_SUBOPTIONS()             => 'suboptions',                    # rfc 2242
@@ -533,7 +533,7 @@ Net::DHCP::Constants - Constants for DHCP codes and options
 
 =head1 VERSION
 
-version 0.7_007
+version 0.7_008
 
 =head1 SYNOPSIS
 
