@@ -8,9 +8,9 @@ use warnings;
 use 5.8.0;
 
 package Net::DHCP::Packet;
-$Net::DHCP::Packet::VERSION = '0.7_007'; # TRIAL
-
-$Net::DHCP::Packet::VERSION = '0.7007';use Carp;
+$Net::DHCP::Packet::VERSION = '0.7_008'; # TRIAL
+$Net::DHCP::Packet::VERSION = '0.7008';
+use Carp;
 use Net::DHCP::Constants qw(:DEFAULT :dhcp_hashes :dhcp_other %DHO_FORMATS %SUBOPTION_FORMATS);
 use Net::DHCP::Packet::Attributes qw(:all);
 use Net::DHCP::Packet::IPv4Utils qw(:all);
@@ -673,7 +673,6 @@ sub toString {
             }
             else {
                 $value = $self->getOptionRaw($key);
-		print "went here for $key\n";
             }
 
             # convert to printable text
@@ -733,6 +732,7 @@ sub unpacksuboptions {     # prints a human readable suboptions
 
 }
 
+
 sub packclientid {
    return shift
    # croak('pack clientid field still WIP');
@@ -743,15 +743,53 @@ sub unpackclientid {
     my $clientid = shift
       or return;
 
+
+## See https://tools.ietf.org/html/rfc2132#section-9.14
+## See also https://tools.ietf.org/html/rfc4361
+#   The code for this option is 61, and its minimum length is 2.
+#
+#   Code   Len   Type  Client-Identifier
+#   +-----+-----+-----+-----+-----+---
+#   |  61 |  n  |  t1 |  i1 |  i2 | ...
+#   +-----+-----+-----+-----+-----+---
+#
+
     my $type = unpack('C',substr( $clientid, 0, 1 ));
 
-    if ($type == 0) { # text
+    if ($type == 0) { # fqdn i.e. text
         return substr( $clientid, 1, length($clientid) )
     }
+
+    # Types from here on down are from 'Address Resolution Protocol' section in RFC1700
     if ($type == 1) { # ethernet
         return unpack('H*',substr( $clientid, 1, length($clientid) ))
     }
 
+    # Copied here for future reference
+    # Number Hardware Type (hrd)                           References
+    # ------ -----------------------------------           ----------
+    #     1 Ethernet (10Mb)                                    [JBP]
+    #     2 Experimental Ethernet (3Mb)                        [JBP]
+    #     3 Amateur Radio AX.25                                [PXK]
+    #     4 Proteon ProNET Token Ring                          [JBP]
+    #     5 Chaos                                              [GXP]
+    #     6 IEEE 802 Networks                                  [JBP]
+    #     7 ARCNET                                             [JBP]
+    #     8 Hyperchannel                                       [JBP]
+    #     9 Lanstar                                             [TU]
+    #    10 Autonet Short Address                             [MXB1]
+    #    11 LocalTalk                                         [JKR1]
+    #    12 LocalNet (IBM PCNet or SYTEK LocalNET)             [JXM]
+    #    13 Ultra link                                        [RXD2]
+    #    14 SMDS                                              [GXC1]
+    #    15 Frame Relay                                        [AGM]
+    #    16 Asynchronous Transmission Mode (ATM)              [JXB2]
+    #    17 HDLC                                               [JBP]
+    #    18 Fibre Channel                            [Yakov Rekhter]
+    #    19 Asynchronous Transmission Mode (ATM)      [Mark Laubach]
+    #    20 Serial Line                                        [JBP]
+    #    21 Asynchronous Transmission Mode (ATM)              [MXB1]
+
     return $clientid
 
 }
@@ -825,7 +863,7 @@ Net::DHCP::Packet - Object methods to create a DHCP packet.
 
 =head1 VERSION
 
-version 0.7_007
+version 0.7_008
 
 =head1 SYNOPSIS
 
@@ -1037,6 +1075,9 @@ Remove option from option list.
 
 returns the packed Client-identifier (pass-through currently)
 
+See L<https://tools.ietf.org/html/rfc2132#section-9.14>
+See also L<https://tools.ietf.org/html/rfc4361>
+
 =item I<unpackclientid>
 
 returns the unpacked clientid.
@@ -1046,7 +1087,10 @@ Decodes:
  type 1 as a mac address (hex string)
  everything is passed through
 
-=item I<packsipserv( VALUE)>
+See L<https://tools.ietf.org/html/rfc2132#section-9.14>
+See also L<https://tools.ietf.org/html/rfc4361>
+
+=item I<packsipserv( VALUE )>
 
 returns the packed sip server field (pass-through currently)
 
